@@ -20,6 +20,7 @@ class URLs:
         self.getCt = "ct"
         self.doAllNew = "do_all_new"
         self.doAllAlter = "do_all_alter"
+        self.doAllSummer = "do_all_summer"
 
     def base_url(self):
         return self.base_url
@@ -59,6 +60,10 @@ class URLs:
     def doAllAlter_url(self):
         url = self.base_url % self.doAllAlter
         return url
+
+    def doAllSummer_url(self):
+        url = self.base_url % self.doAllSummer
+        return url
     
 
 class Api():
@@ -155,4 +160,8 @@ class Api():
     
     def do_All_alter(self, session_id, content):
         """Returns all. Custom format 2"""
-        return self.__get_data(session_id, self.url.doAllAlter_url(), content)
\ No newline at end of file
+        return self.__get_data(session_id, self.url.doAllAlter_url(), content)
+
+    def do_All_summer(self, session_id, content):
+        """Returns all. Custom format 3"""
+        return self.__get_data(session_id, self.url.doAllSummer_url(), content)
\ No newline at end of file
